@@ -1,5 +1,5 @@
 package MetaCPAN::Role::Fastly;
-$MetaCPAN::Role::Fastly::VERSION = '0.01';
+$MetaCPAN::Role::Fastly::VERSION = '0.02';
 # COPY BELOW HERE INTO MetaCPAN::Role::Fastly
 
 use Moose::Role;
@@ -116,6 +116,9 @@ sub perform_purges {
         $self->reset_surrogate_keys();
     }
 
+    # Needed for MC tests!
+    return 1;
+
 }
 
 =head2 datacenters()
